* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Styles and Patterns](https://help.sap.com/docs/leanix/ea/styles-and-patterns)
  * Fact Sheet Shape Templates
